pub struct RoiRegion {
pub x: i32,
pub y: i32,
pub width: u32,
pub height: u32,
pub priority: f64,
pub label: String,
}Expand description
A rectangular region of interest within a frame.
Fields
x: i32Left edge in pixels.
y: i32Top edge in pixels.
width: u32Width in pixels.
height: u32Height in pixels.
priority: f64Priority weight (0.0 = ignore, 1.0 = normal, >1.0 = boosted).
label: StringOptional label for the region.
Implementations
Sourceimpl RoiRegion
impl RoiRegion
Sourcepub fn new(x: i32, y: i32, width: u32, height: u32) -> Self
pub fn new(x: i32, y: i32, width: u32, height: u32) -> Self
Creates a new ROI region with default priority.
Sourcepub fn with_priority(
x: i32,
y: i32,
width: u32,
height: u32,
priority: f64,
) -> Self
pub fn with_priority( x: i32, y: i32, width: u32, height: u32, priority: f64, ) -> Self
Creates a new ROI region with a given priority weight.
Sourcepub fn contains(&self, px: i32, py: i32) -> bool
pub fn contains(&self, px: i32, py: i32) -> bool
Checks whether a pixel coordinate falls inside this region.
Sourcepub fn intersection_area(&self, other: &Self) -> u64
pub fn intersection_area(&self, other: &Self) -> u64
Returns the intersection area with another region, or 0 if they don’t overlap.